/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */

#ifndef HARKIO_INITIALIZEDFLAG_HPP_
#define HARKIO_INITIALIZEDFLAG_HPP_

/** @file InitializedFlag.hpp
 * @brief InitializedFlag class definition.
 */

namespace harkio2
{

/** @brief A flag indicates an object has been initialized.
 */
class InitializedFlag
{
    bool initialized_;
public:
    /** @brief Constructs a flag indicating the given state.
     * This constructor is implicit because this class
     * can be used in the same way as builtin bool.
     * @param initialized The state of initialization.
     */
    InitializedFlag(bool initialized = false)
        : initialized_(initialized)
    { }

    /** @brief Returns the state of initialization.
     * @return The state of initialization
     */
    operator bool() const
    {
        return this->initialized_;
    }
};

}

#endif /* HARKIO_INITIALIZEDFLAG_HPP_ */
