#ifndef HARKIO_HARKCONFIG_HARKCONFIGFILEXMLWRITER_HPP_
#define HARKIO_HARKCONFIG_HARKCONFIGFILEXMLWRITER_HPP_

#include <ostream>
#include <boost/shared_ptr.hpp>
#include <boost/scoped_ptr.hpp>
#include <harkio2/harkconfig/HarkConfigFileWriter.hpp>

/** @file HarkConfigFileXMLWriter.hpp
 * @brief HarkConfigFileXMLWriter class definition.
 */

namespace harkio2
{
namespace harkconfig
{

class HarkConfigFile;

/** @brief XML file writer for HarkConfigFile.
 * This class writes HarkConfigFile data structure to a XML file.
 */
class HarkConfigFileXMLWriter :
    public harkio2::harkconfig::HarkConfigFileWriter
{
public:
    /** @brief Constructs a xml writer.
     * @param out The output stream.
     */
    HarkConfigFileXMLWriter(std::ostream& out);

    /** @brief Virtual destructor.
     * This destructor must be declared as non-inline function
     * so that boost::scoped_ptr can delete its content.
     */
    virtual ~HarkConfigFileXMLWriter();

    /** @brief Writes HarkConfigFile data structure.
     * Writes data to the output stream specified by a constructor.
     * @param data The data to write.
     */
    virtual void Write(boost::shared_ptr<harkio2::harkconfig::HarkConfigFile> data) throw (harkio2::InvalidHarkFile);

    virtual void Write(const harkio2::harkconfig::HarkConfigFile& o) throw (harkio2::InvalidHarkFile);
    virtual void Write(const harkio2::harkconfig::ImpulseResponseListFile1_0& o) throw (harkio2::InvalidHarkFile);
    virtual void Write(const harkio2::harkconfig::ImpulseResponseListFile2_0& o) throw (harkio2::InvalidHarkFile);
    virtual void Write(const harkio2::harkconfig::TSPListFile1_0& o) throw (harkio2::InvalidHarkFile);
    virtual void Write(const harkio2::harkconfig::TSPListFile2_0& o) throw (harkio2::InvalidHarkFile);
    virtual void Write(const harkio2::harkconfig::MicArrayLocationFile2_0& o) throw (harkio2::InvalidHarkFile);
    virtual void Write(const harkio2::harkconfig::NoiseLocationFile2_0& o) throw (harkio2::InvalidHarkFile);

#ifdef HARKIO_UNITTEST
public:
#else
private:
#endif
    /// @brief Helper class.
    class Helper;
    boost::scoped_ptr<Helper> helper;
private:
    /// @brief Data destination.
    std::ostream& out;
};

}
}

#endif // HARKIO_HARKCONFIG_HARKCONFIGFILEXMLWRITER_HPP_

