#include <harkio2/Endian.hpp>

#include <cstring>

/** @file Endian.cpp
 * @brief Endian class definition.
 */

namespace harkio2
{

void Endian::LittleToHost(void* dst, const void* src, size_t n)
{
    if (HostIsLittle())
    {
        memcpy(dst, src, n);
    }
    else
    {
        MemcpySwap(dst, src, n);
    }
}

void Endian::BigToHost(void* dst, const void* src, size_t n)
{
    if (HostIsBig())
    {
        memcpy(dst, src, n);
    }
    else
    {
        MemcpySwap(dst, src, n);
    }
}

void Endian::HostToLittle(void* dst, const void* src, size_t n)
{
    LittleToHost(dst, src, n);
}

void Endian::HostToBig(void* dst, const void* src, size_t n)
{
    BigToHost(dst, src, n);
}

void Endian::MemcpySwap(void* dst, const void* src, size_t n)
{
    char* dst_ = reinterpret_cast<char*>(dst);
    const char* src_ = reinterpret_cast<const char*>(src);

    for (size_t i = 0; i < n; ++i)
    {
        dst_[i] = src_[n - 1 - i];
    }
}

}

